@@ -99,8 +99,7 @@ class KAddDeviceContainer : public KDialog
     bool _advanced;    
   
   protected slots:
-    void toggleApplyButtonSlot( const QString & );
-    void toggleApplyButtonSlot( int );
+    void toggleApplyButtonSlot( );
     void toggleAdvancedOptionsSlot(bool enabled );
     void verifyDeviceInfoSlot();
     void advancedOptionsSlot();
